<?php

	lt_include( PLOG_CLASS_PATH."class/security/pipelinefilter.class.php" );
    lt_include( PLOG_CLASS_PATH."class/file/file.class.php" );	
    lt_include( PLOG_CLASS_PATH."class/config/config.class.php" );	


    /**
     * Checks to see if the subscription checkbox was checked, and if so,
     * requires the email address to be valid. This
     * filter only works if the incoming request has the "op" parameter as
     * "AddComment", because then it means that we're posting a comment. If it's not
     * like that, then we'll quit. Otherwise, the process will continue as normally.
     */
	class SubscribeFilter extends PipelineFilter{
    	function SubscribeFilter($pipelineRequest){
        	$this->PipelineFilter($pipelineRequest);
        }

        function filter(){
        	// get some info
            $blogInfo = $this->_pipelineRequest->getBlogInfo();
            $request  = $this->_pipelineRequest->getHttpRequest();

        	// check if this section has been enabled or disabled
            $blogSettings = $blogInfo->getSettings();
		    $pluginEnabled = $blogSettings->getValue( "plugin_subscribe_enabled" );
            if(!$pluginEnabled)
            	return new PipelineResult();

            // we only have to filter the contents if the user is posting a comment
            // so there's no point in doing anything else if that's not the case
            if($request->getValue("op") != "AddComment")
            	return new PipelineResult();

            // if this is already rejected, there is no reason to do anything here
            if($this->_pipelineRequest->getRejectedState())
                return new PipelineResult();

                // checkbox not active, don't do anything
            if(!$request->getValue("subscribe"))
                return new PipelineResult();

                // email is required: validate it.
            $emailAddress = $request->getValue("userEmail");

                // check if they are already logged in (ie. an authenticated commenter)
            $userInfo = SessionManager::getUserInfoFromSession();  
            if($emailAddress == "" && $userInfo){
                $emailAddress = $userInfo->getEmail();
            }
            lt_include( PLOG_CLASS_PATH."class/data/validator/emailvalidator.class.php" );

            $emailValidator = new EmailValidator();
            if(!$emailValidator->validate($emailAddress)){
                $locale = $blogInfo->getLocale();
                return new PipelineResult(false, 500,
                                          $locale->tr("error_incorrect_email_address"));
            }

                // if everything went fine, we can say so by returning
                // a positive PipelineResult object
            return new PipelineResult();
        }
    }
?>
